@@ -1,4 +1,5 @@
 use strict;
+use warnings;
 
 package Test::Deep::Number;
 use Carp qw( confess );
@@ -10,11 +11,29 @@ use vars qw( @ISA );
 
 use Data::Dumper qw(Dumper);
 
+use Scalar::Util;
+
 sub init
 {
 	my $self = shift;
 
-	$self->{val} = shift;
+	$self->{val} = shift(@_) + 0;
+
+	my $mode = shift;
+
+	$mode = "loose" unless defined $mode;
+
+	if($mode !~ /^(strict|loose)$/)
+	{
+		die "'$mode' is not a valid mode";
+	}
+
+	if ($mode eq "strict" and $Scalar::Util::VERSION < 1.10)
+	{
+		die "You need Scalar::Util 1.10 or greater to use number's strict mode";
+	}
+
+	$self->{mode} = $mode;
 }
 
 sub descend
@@ -26,7 +45,21 @@ sub descend
 
 	push(@Test::Deep::Stack, \%data);
 
-	my $ok = $d1 == $self->{val};
+	if ($self->{mode} eq "strict")
+	{
+		if (! Scalar::Util::looks_like_number($d1))
+		{
+			# if we're being strict, fail because $d1 doesn't look like a number
+			return 0 if $self->{"mode"} eq "strict";
+		}
+	}
+
+	my $ok;
+	{
+		no warnings 'numeric';
+
+		$ok = $d1 == $self->{val};
+	}
 
 	pop @Test::Deep::Stack if $ok;
 
